Crate quokka_handler

Crate quokka_handler 

Structs

Error
ErrorObject
FormHandler
Handles a POST request with the axum::extract::Form extractor and passes it to the provided DataHandler (in H).
JsonHandler
Handles a POST request with the axum::extract::Json extractor and passes it to the provided DataHandler (in H).
JsonRenderer
Gets data via a DataLoader and outputs it as a JSON
JsonResponse
A response object folling the jsonapi format.
StaticTemplate
StaticTemplateContext
TemplateRenderer
Gets some data via the provided <L: DataLoader> and renders it to the template provided in the Self::path field.

Enums

HandlerError
Link

Traits

DataHandler
Handles incoming data
DataLoader
Give a generic piece of data based on the request parameters. This data might be used together with different handlers like the crate::FormHandler or the crate::JsonHandler to render either HTML or JSON data. In case it is paired with such a handler and some error happens in this handler, you will have a axum::extract::Extension<crate::HandlerError> in your Self::Args so you can handle the error case

Type Aliases

DefaultMeta
Result