pub struct FormHandler<H, R> { /* private fields */ }Expand description
Handles a POST request with the axum::extract::Form extractor and passes it to the provided DataHandler (in H).
The Self::response_renderer will be used for rendering a response, it will be provided with a HandlerError<DataHandler::Error> as an axum::extract::Extension so it can react to errors during handling. Additionally it will be provided with the DataHandler::Extension so that additional data can be used for communicating to the user.
Note: When using the Into::into call to convert this handler into a MethodRouter for axum, the Self::response_renderer will also
be used for the MethodRouter::get call
Implementations
Sourceimpl<P, R> FormHandler<P, R>
impl<P, R> FormHandler<P, R>