Structs
- Error
- Error
Object - Form
Handler - Handles a POST request with the axum::extract::Form extractor and passes it to the provided DataHandler (in H).
- Json
Handler - Handles a POST request with the axum::extract::Json extractor and passes it to the provided DataHandler (in H).
- Json
Renderer - Gets data via a DataLoader and outputs it as a JSON
- Json
Response - A response object folling the jsonapi format.
- Source
- Static
Template - Static
Template Context - Template
Renderer - Gets some data via the provided <L: DataLoader> and renders it to the template provided in the Self::path field.
Enums
Traits
- Data
Handler - Handles incoming data
- Data
Loader - Give a generic piece of data based on the request parameters. This data might be used together with different handlers like the crate::FormHandler or the crate::JsonHandler to render either HTML or JSON data. In case it is paired with such a handler and some error happens in this handler, you will have a axum::extract::Extension<crate::HandlerError> in your Self::Args so you can handle the error case